#if !defined(__simlib_h)
#define __simlib_h

/***********************************************************************
	Definitions of Simlib classes
      
     See simlib.cpp for further details

  Author: Gerhard HOLTKAMP                   17-JUL-2000
 ***********************************************************************/

class RKF45      // Runge-Kutta-Fehlberg 4(5) Integration
 {
  public:
	 RKF45 (int nq);  // nq is the number of dependent variables (equations)
	 virtual ~RKF45();
   void ResetNeq (int nq);
	 void SetTolerance (double vtol, int rtol = 1);
	 void SetMaxIter (int mxi);   // set maximum number of iterations
	 int GetConOk ();   // check whether construction of class went OK
	 void RKF45Step(double xin, double hin, double yin[],
						 void (*Fun)(double x, double y[], double z[]),
						 double& xout, double& hout, double yout[]);  // calculate 1 step

  private:
	 int neq;  // number of equations (dependent variables)
	 double x; // independent variable
	 double* y; // array of dependent variables
	 double* f; // array of intermediate derivatives
	 double* te; // array of local truncation errors
	 int constrok; // 1 if construction of class OK, 0 otherwise
	 int maxiter;  // maximum number of iteration per step. 0 if no limit.
         int reltol; // 1 if relative tolerance given, 0 for absolute tolerance
         double tol; // tolerance
         double h;   // current stepsize
 };

class RK4      // Runge-Kutta Integration of Order 4
 {
  public:
	 RK4 (int nq);  // nq is the number of dependent variables (equations)
	 virtual ~RK4();
	 int GetConOk ();   // check whether construction of class went OK
	 void RK4Step(double xin, double h, double yin[],
						 void (*Fun)(double x, double y[], double z[]),
						 double& xout, double yout[]);  // calculate 1 step

  private:
	 int neq;  // number of equations (dependent variables)
	 double x; // independent variable
	 double* y; // array of dependent variables
	 double* f; // array of intermediate derivatives
	 int constrok; // 1 if construction of class OK, 0 otherwise
 };

#endif         // __simlib_h sentry.

