/********************************************************************************
********************************************************************************/

#include <QtGui>

#include "stpassdialog.h"
#include "satcalview.h"

//QT_BEGIN_NAMESPACE

StPassDialog::StPassDialog()
{
        setObjectName(QString::fromUtf8("StPassDialog"));
        resize(491, 477);
        passEdit = new QTextEdit(this);
        passEdit->setObjectName(QString::fromUtf8("passEdit"));
        passEdit->setGeometry(QRect(10, 10, 460, 410));
        passEdit->setReadOnly(true);
        closeButton = new QPushButton(this);
        closeButton->setObjectName(QString::fromUtf8("closeButton"));
        closeButton->setGeometry(QRect(360, 430, 107, 29));
        closeButton->setDefault(true);
        saveButton = new QPushButton(this);
        saveButton->setObjectName(QString::fromUtf8("saveButton"));
        saveButton->setGeometry(QRect(20, 430, 110, 29));
        gtrackButton = new QPushButton(this);
        gtrackButton->setObjectName(QString::fromUtf8("gtrackButton"));
        gtrackButton->setGeometry(QRect(150, 430, 110, 29));
        QWidget::setTabOrder(passEdit, closeButton);
        QWidget::setTabOrder(closeButton, saveButton);
        QWidget::setTabOrder(saveButton, gtrackButton);

        connect(closeButton, SIGNAL(clicked()), this, SLOT(accept()));
        connect(saveButton, SIGNAL(clicked()), this, SLOT(saveSlot()));
        connect(gtrackButton, SIGNAL(clicked()), this, SLOT(gtrackSlot()));

        setWindowTitle(QApplication::translate("StPassDialog", "Pass Details", 0, QApplication::UnicodeUTF8));
        closeButton->setText(QApplication::translate("StPassDialog", "&Close", 0, QApplication::UnicodeUTF8));
        closeButton->setShortcut(QApplication::translate("StPassDialog", "Alt+C", 0, QApplication::UnicodeUTF8));
#ifndef QT_NO_TOOLTIP
        saveButton->setToolTip(QApplication::translate("StPassDialog", "Saves the Pass Details information on the SatCal Save-File.", 0, QApplication::UnicodeUTF8));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_WHATSTHIS
        saveButton->setWhatsThis(QApplication::translate("StPassDialog", "The angles will be without the degree sign. Longitude and latitude are always in decimal degrees and with 5 decimal points. This should make further processing by other programs easier.", 0, QApplication::UnicodeUTF8));
#endif // QT_NO_WHATSTHIS
        saveButton->setText(QApplication::translate("StPassDialog", "&Save", 0, QApplication::UnicodeUTF8));
        saveButton->setShortcut(QApplication::translate("StPassDialog", "Alt+S", 0, QApplication::UnicodeUTF8));
#ifndef QT_NO_TOOLTIP
        gtrackButton->setToolTip(QApplication::translate("StPassDialog", "Copy groundtrack on save file.", 0, QApplication::UnicodeUTF8));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_WHATSTHIS
        gtrackButton->setWhatsThis(QApplication::translate("StPassDialog", "Time, latitude and longitude will be copied to the save file. They can then be used by other programs for producing map overlays etc.", 0, QApplication::UnicodeUTF8));
#endif // QT_NO_WHATSTHIS
        gtrackButton->setText(QApplication::translate("StPassDialog", "&G-Track", 0, QApplication::UnicodeUTF8));
        gtrackButton->setShortcut(QApplication::translate("StPassDialog", "Alt+G", 0, QApplication::UnicodeUTF8));
};

void StPassDialog::setParams( int fsz )
{
  QString s;
  int mm, clnt;
  double t;

  passEdit->setFontPointSize(fsz);  
  t = 0;
  clnt = 0;
  mm = vsGetPassDTxt(t, s, false);
   while (mm)
     {                                           
       passEdit->insertPlainText(s);
       clnt++;                    // limit number of lines
       if (clnt < 6250) mm = vsGetPassDTxt(t, s, false);
       else mm = 0;
    };
   vsGetPassDTxt(t, s, true);
   passEdit->insertPlainText(s);
   passEdit->moveCursor(QTextCursor::Start,QTextCursor::MoveAnchor);
   closeButton->setFocus();
}

void StPassDialog::saveSlot()
{
 vsSavePassDt(1);
}

void StPassDialog::gtrackSlot()
{
 vsSavePassDt(2);
}
